/*
 * This file is part of Renewed World Disorder, a GameScript for OpenTTD.
 * This script is more than 90% based on the Renewed City Growth script written by keoz
 * Copyright (C) 2013-2014 keoz, 2020 LaChupacabra
 *
 * It's free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the
 * Free Software Foundation, version 2 of the License.
 *
 */

enum CatLabels
{
	PAXMAIL = 0,
	G_FOOD = 1,
	G_GOODS = 2,
	RAW_IND = 3,
	TR_IND = 4,
	G_IND = 5
}

/* Cargolist of supported industry set's cargos. Used to check if
 * initial ingame cargo list matches the defined setting. Needs to be
 * updated if industry set cargos change.
 */
function FillCargoIDList() {
	switch (GSController.GetSetting("industry_NewGRF")) {
	/* Baseset */
	case(1): // Temperate
		::CargoIDList <- ["PASS","COAL","MAIL","OIL_","LVST","GOOD",
				  "GRAI","WOOD","IORE","STEL","VALU"];
		break;
	case(2): // Arctic
		::CargoIDList <- ["PASS","COAL","MAIL","OIL_","LVST","GOOD",
				  "WHEA","WOOD",null,"PAPR","GOLD","FOOD"];
		break;
	case(3): // Tropical
		::CargoIDList <- ["PASS","RUBR","MAIL","OIL_","FRUT","GOOD",
				  "MAIZ","WOOD","CORE","WATR","DIAM","FOOD"];
		break;
	case(4): // Toyland
		::CargoIDList <- ["PASS","SUGR","MAIL","TOYS","BATT","SWET",
				  "TOFF","COLA","CTCD","BUBL","PLST","FZDR"];
 		break; 
  /* OpenGFX+ / Manpower */
  case(5): // any setup
		::CargoIDList <- ["PASS","COAL","MAIL","OIL_","LVST","GOOD","GRAI","WOOD","IORE",
				  "WATR","VALU","FOOD","STEL","CORE","FRUT","DIAM","PAPR","GOLD","RUBR"];
		break;
	/* FIRS version 3.0.12 */
	case(6): // Temperate basic
		::CargoIDList <- ["PASS","BEER","MAIL","RFPR","CLAY","GOOD","COAL","ENSP","FMSP","FISH",
				  "FRUT","FOOD","IORE","LVST","MILK","SAND","SCMT","STEL"];
		break;
	case(7): // Arctic Basic
		::CargoIDList <- ["PASS","KAOL","MAIL","ENSP","FMSP","GOOD","PAPR","PORE","BEER","WDPR",
				  "PHOS","FOOD","BOOM","ZINC","FISH","SULP","FERT","WOOD","PEAT"];
		break;
	case(8): // Tropic Basic
		::CargoIDList <- ["PASS","BEER","MAIL","BEAN","RFPR","GOOD","JAVA","COPR","CORE","ENSP",
				  "FMSP","FOOD","FISH","FRUT","GRAI","LVST","NITR","OIL_","WOOL"];
		break;
	case(9): // Steeltown
		::CargoIDList <- ["PASS","CMNT","MAIL","QLME","ENSP","VEHI","FMSP","STEL","SLAG","LIME",
				  "SAND","FOOD","MNO2","COAL","IORE","IRON","COKE","PETR","SULP","SCMT","SASH","ZINC"
				  "COPR","RUBR","PIPE","SALT","ACID","CHLO","POWR","VPTS","VBOD",null];
    break;
   case(10): // In a hot country
		::CargoIDList <- ["PASS","BEER","MAIL","BDMT","CASS","GOOD","RFPR","CLAY","JAVA",
          "COPR","CORE","FOOD","DIAM","EOIL","ENSP","FMSP","FRUT","LVST","WDPR","MAIZ",
          "MNO2","NUTS","OIL_","PETR","PHOS","RUBR","SAND","GRVL","WOOD",null,null,
          null];                    
		break;         
  case(11): // Extreme
		::CargoIDList <- ["PASS","BEER","MAIL","AORE","BDMT","GOOD","RFPR","CLAY","COAL",
          "ENSP","FMSP","FOOD","FISH","FRUT","GRAI","IORE","LVST","WDPR","MNSP","METL",
          "MILK","OIL_","PETR","FICR","RCYC","SAND","SCMT","GRVL","SGBT","WOOD","WOOL",
          null];                    
		break;
/* FIRS version 1.4.4M */
	case(12): // Temperate basic
		::CargoIDList <- ["PASS","COAL","MAIL",null,"LVST","GOOD",null,null,"IORE","STEL",
				  "MILK","FOOD",null,"FRUT",null,null,"CLAY","SAND","MNSP",null,
				  "SCMT","FMSP",null,"RFPR","ENSP",null,null,null,null,"BEER"];
		break;
	case(13): // Arctic basic
		::CargoIDList <- ["PASS",null,"MAIL","OIL_","LVST","GOOD","GRAI","WOOD","IORE",null,
				  null,"FOOD",null,"PAPR","FISH",null,"CLAY",null,"MNSP",null,
				  null,"FMSP",null,"RFPR","ENSP","PETR",null,null,null,"BEER"];
		break;
	case(14): // Tropic basic
		::CargoIDList <- ["PASS",null,"MAIL","OIL_","LVST","GOOD","BEAN",null,null,null,
				  "JAVA","FOOD","SGBT","FRUT",null,"WOOL",null,"NITR","MNSP","VPTS",
				  null,"FMSP",null,"RFPR","ENSP",null,null,"AORE"];
		break;
	case(15): // Heart of Darkness
		::CargoIDList <- ["PASS","DIAM","MAIL","OIL_",null,"GOOD","GRAI","WOOD","CORE",null,
				  "JAVA","FOOD","SGBT","FRUT","FISH",null,null,null,"MNSP",null,
				  "SUGR","FMSP","FICR",null,"ENSP",null,null,"RUBR","BDMT","BEER"];
		break;
  case(16): // Firs economy
		::CargoIDList <- ["PASS","COAL","MAIL","OIL_","LVST","GOOD","GRAI","WOOD","IORE","STEL",
				  "MILK","FOOD","SGBT","FRUT","FISH","WOOL","CLAY","SAND","MNSP","WDPR",
				  "SCMT","FMSP","FICR","RFPR","ENSP","PETR","GRVL","AORE","BDMT","BEER",
				  null,"RCYC"];                    
		break;
	/* ECS 1.2 - Included vectors:
	 * ECS Town vector 1.2 (R163)
	 * ECS Houses 1.2 (R185)
	 * ECS Basic vector II 1.2 (R644)
	 * ECS Chemicals vector II 1.2 (R264)
	 * ECS Machinery Vector 1.2 (R415)
	 * ECS Wood vector 1.2 (R226)
	 * ECS Agricultural vector 1.2 (R685)
	 */
	case(17):
		::CargoIDList <- ["PASS","COAL","MAIL","OIL_","LVST","GOOD","CERE","WOOD","IORE","STEL",
				  "GOLD","FOOD","PAPR","FRUT","FISH","WOOL",null,"SAND","GLAS","WDPR",
				  "DYES","FERT","OLSD","RFPR","VEHI","PETR","AORE","WATR","BDMT","FICR",
				  null,"TOUR"];
		break;
	/* YETI 0.1.6 - tired yetis*/
	case(18):
		::CargoIDList <- ["PASS","GRVL","MAIL","WOOD","BDMT",null,"GRAI","FRUT","FOOD",null,
				  "OIL_",null,"STEL","PETR","BATT","VEHI","YETI","CLAY","LVST","URAN",
				  "IORE","YETY"];
		break;
	/* AuzInd2 */
	case(19):
		::CargoIDList <- ["PASS","COAL","MAIL","OIL_","LVST","GOOD","GRAI","WOOD","IORE",
    "STEL","MILK","FOOD","PAPR","MEAT","FISH","WOOL","CLAY","SAND","MNSP","WDPR","SUGR",
    "CORE","FICR","RFPR","PCL_","FUEL","GRVL","FRUT","BDMT","BEER","ENSP","FRVG"];
		break;
	/* NAIS */
	case(20):
		::CargoIDList <- ["PASS","AORE","MAIL","BDMT","RFPR","GOOD","CLAY","COAL","CORE","FMSP",
				  "FICR","FOOD","FISH","PETR","GLAS","GRAI","IORE","LVST","WDPR","ENSP","METL",
				  "MILK","PORE","OIL_","PAPR","FRUT","SAND","SCMT","GRVL","URAN","VALU","WOOD"];
		break;
	/* FERNZ 6057M */
	case(21):
		::CargoIDList <- ["PASS","BEER","MAIL","AORE","BDMT","GOOD","RFPR","CLAY","COAL",
          "ENSP","FMSP","FOOD","FISH","FRUT","GRAI","GOLD","ISND","LVST","WDPR","PAPR","METL",
          "MILK","OIL_","PETR","RCYC","SAND","SCMT","SALT","GRVL","SGBT","WOOD","WOOL"]; 
		break;
	/* SPI 1.32: Full set */
	case(22):
		::CargoIDList <- ["PASS","COAL","MAIL","OIL_","LVST","GOOD","GRAI","WOOD","IORE","STEL",
				  "MILK","FOOD","PAPR","FRUT","FISH","TXTL","CLAY","SAND","MNSP","WDPR",
				  "SCMT","FMSP","FICR","RFPR","ENSP",null,"GRVL","AORE","BDMT","BEER",
				  null,"RCYC"]; 
		break;
	default: break;
	}

	// This is used to add all null IDs after the end of active used cargos
	local missing_cargo = 32 - ::CargoIDList.len();
	for (local i = 0; i < missing_cargo; i++) {
		for (local i = 0; i < missing_cargo; i++) ::CargoIDList.append(null);
	}
}

/* Here are defined the cargo categories and other data for each
 * set. Follow explanations below to change category data.
 */
function DefineCargosBySettings()
{
	/* Setup global cargo variables, per cargo categories: (Cat 1:
	 * Passengers and mail, Cat 2: General food, Cat 3: General
	 * goods, Cat 4: Raw industrial materials, Cat 5: transformed
	 * indudstrial goods). For base sets, only 3 categories are
	 * defined (PaxMail, General goods (including food),
	 * industrial goods).
	 *
	 * For each industry set, we define:
	 * ::CargoCat: the base categories of cargo. For each
	 * category, an array of cargo types is created. For cargo Id
	 * references, enable debugging and watch at the AI/GameScript
	 * log.
	 * ::CargoCatList: a list of used cargo categories; see enum
	 * CargoCategories
	 * ::CargoMinPopDemand: minimal town population at which a
	 * cargo category is required
	 * ::CargoPermille: a factor defining the growth of cargo category
	 * requirements
	 * ::CargoDecay: defines the part of the stockpiled cargos
	 * which is lost each month
	 */
	local industry_setting = GSController.GetSetting("industry_NewGRF");
	switch (industry_setting) {
		case(1): // Base temperate
			::CargoCat <- [[0,2],
				       [5,10],
				       [1,3,4,6,7,8,9]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_GOODS,CatLabels.G_IND];
			::CargoMinPopDemand <- [0,1000,1000];
			::CargoPermille <- [60,40,25];
			::CargoDecay <- [0.4,0.2,0.1];
			break;
		case(2): //Base arctic
			::CargoCat <- [[0,2],
				       [5,10,11],
				       [1,3,4,6,7,9]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_GOODS,CatLabels.G_IND];
			::CargoMinPopDemand <- [0,1000,1000];
			::CargoPermille <- [60,40,25];
			::CargoDecay <- [0.4,0.2,0.1];
			break;
		case(3): //Base tropical
			::CargoCat <- [[0,2],
				       [5,9,10,11],
				       [1,3,4,6,7,8]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_GOODS,CatLabels.G_IND];
			::CargoMinPopDemand <- [0,1000,1000];
			::CargoPermille <- [60,40,25];
			::CargoDecay <- [0.4,0.2,0.1];
			break;
		case(4): //Base toyland
			::CargoCat <- [[0,2],
				       [3,5,11],
				       [1,4,6,7,8,9,10]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_GOODS,CatLabels.G_IND];
			::CargoMinPopDemand <- [0,1000,1000];
			::CargoPermille <- [60,40,25];
			::CargoDecay <- [0.4,0.2,0.1];
			break;
  	case(5): // OpenGFX+ / Manpower - any setup
			::CargoCat <- [[0,2],
				       [5,9,10,11,15,17],
				       [4,6,7,14,16],
               [1,3,8,12,13,18]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000];
			::CargoPermille <- [60,30,10,25];
			::CargoDecay <- [0.4,0.2,0.1,0.1];
			break;
		case(6): // FIRS 3.0.12 - Temperate Basic
			::CargoCat <- [[0,2],
				       [1,5,11],
				       [8,9,10,13,14],
				       [4,6,7,12,15,16,17]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000];
			::CargoPermille <- [60,30,15,25];
			::CargoDecay <- [0.4,0.2,0.1,0.1];
			break;
		case(7): // FIRS 3.0.12 - Arctic Basic
			::CargoCat <- [[0,2],
				       [5,6,8,11,12,13,16],
				       [1,4,9,14,18],
				       [3,7,10,15]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000];
			::CargoPermille <- [60,30,15,25];
			::CargoDecay <- [0.4,0.2,0.1,0.1];
			break;
		case(8): // FIRS 3.0.12 - Tropic Basic
			::CargoCat <- [[0,2],
				       [1,5,6,7,11,18],
				       [3,10,12,13,14,15],
				       [4,8,9,16,17]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000];
			::CargoPermille <- [60,30,15,25];
			::CargoDecay <- [0.4,0.2,0.1,0.1];
			break;
		case(9): // FIRS 3.0.12 - Steeltown
			::CargoCat <- [[0,2],
				       [1,5,6,11,24,27,28],
				       [3,4,7,8,9,10,12,13,14,15,16,17,18,19,20,21,22,23,25,26,29,30]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_GOODS,CatLabels.G_IND];
			::CargoMinPopDemand <- [0,1000,1000];
			::CargoPermille <- [60,40,50];
			::CargoDecay <- [0.4,0.2,0.1];
			break;
		case(10): // FIRS 3.0.12 - In a hot country
			::CargoCat <- [[0,2],
 				       [3],
				       [1,5,8,11,12,13,20,22,23,24],
				       [4,15,16,17,18,19,21,25,28],
				       [6,7,9,10,14,26,27]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_FOOD,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000,1000];
			::CargoPermille <- [60,25,20,15,30];
			::CargoDecay <- [0.4,0.2,0.2,0.1,0.1];
			break;
		case(11): // FIRS 3.0.12 - Extreme
			::CargoCat <- [[0,2],
				       [4],
               [1,5,11,13,22],
				       [10,12,14,16,17,18,20,23,24,28,29,30],
				       [3,6,7,8,9,15,19,21,25,26,27]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_FOOD,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000,1000];
			::CargoPermille <- [60,25,20,15,30];
			::CargoDecay <- [0.4,0.2,0.2,0.1,0.1];
			break;
		case(12): // FIRS 1.4.4M - Temperate Basic
			::CargoCat <- [[0,2],
				       [5,11,29],
				       [4,10,13,18,21],
				       [1,8,9,16,17,20,23,24]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000];
			::CargoPermille <- [60,30,15,25];
			::CargoDecay <- [0.4,0.2,0.1,0.1];
			break;
		case(13): // FIRS 1.4.4M - Arctic Basic
			::CargoCat <- [[0,2],
				       [5,11,13,25,29],
				       [4,6,7,14,16,18,21],
				       [3,8,23,24]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000];
			::CargoPermille <- [60,30,15,25];
			::CargoDecay <- [0.4,0.2,0.1,0.1];
			break;
		case(14): // FIRS 1.4.4M - Tropic Basic
			::CargoCat <- [[0,2],
				       [5,10,11,23,27],
				       [4,6,12,13,15,18,21],
				       [3,9,17,19,24]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000];
			::CargoPermille <- [60,30,15,25];
			::CargoDecay <- [0.4,0.2,0.1,0.1];
			break;
		case(15): // FIRS 1.4.4M - Heart of the Darkness
			::CargoCat <- [[0,2],
				       [1,5,10,11,27,28,29],
				       [6,7,12,13,14,18,20,21,22],
				       [3,8,24]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000];
			::CargoPermille <- [60,30,15,25];
			::CargoDecay <- [0.4,0.2,0.2,0.1];
			break;
    case(16): // FIRS 1.4.4M - Firs Economy
			::CargoCat <- [[0,2],
				       [28],
				       [5,11,13,25,29],
				       [4,6,7,10,12,14,15,18,19,21,22,31],
				       [1,3,8,9,16,17,20,23,24,26,27]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_FOOD,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000,1000];
			::CargoPermille <- [60,25,20,15,30];
			::CargoDecay <- [0.4,0.2,0.2,0.1,0.1];
			break;
		case(17): //ECS
			::CargoCat <- [[0,2,31],
				       [28],
				       [5,10,11,25,27],
				       [4,6,7,12,13,14,15,18,19,20,21,22,29],
				       [1,3,8,9,17,23,24,26]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_FOOD,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000,1000];
			::CargoPermille <- [60,25,20,15,30];
			::CargoDecay <- [0.4,0.2,0.2,0.1,0.1];
			break;
		case(18): //YETI 0.1.6 - tired yetis
			::CargoCat <- [[0,2,16,21],
				       [4],
				       [8],
				       [6,7,18],
				       [1,3,10,12,13,14,15,17,19,20]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_FOOD,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000,1000];
			::CargoPermille <- [60,25,20,15,30];
			::CargoDecay <- [0.4,0.2,0.2,0.1,0.1];
			break;
 		case(19): //AuzInd2
			::CargoCat <- [[0,2,24],
				       [28],
				       [5,11,12,13,15,29,31],
				       [4,6,7,10,14,20,22],
				       [1,3,8,9,16,17,18,19,21,23,25,30]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_FOOD,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000,1000];
			::CargoPermille <- [60,25,20,15,30];
			::CargoDecay <- [0.4,0.2,0.2,0.1,0.1];
			break;
    case(20): //NAIS 1.0.6
			::CargoCat <- [[0,2],
				       [3],
				       [5,11,13,30],
				       [9,10,12,14,15,17,18,21,24,25,31],
				       [1,4,6,7,8,16,19,20,22,23,26,27,28,29]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_FOOD,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000,1000];
			::CargoPermille <- [60,25,20,15,30];
			::CargoDecay <- [0.4,0.2,0.2,0.1,0.1];
			break;
    case(21): //FIRS Fernz
			::CargoCat <- [[0,2],
				       [4],
				       [1,5,11,13,15,19,23],
				       [10,12,14,17,18,21,24,27,29,30,31],
				       [3,6,7,8,9,16,20,22,25,26,28]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_FOOD,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000,1000];
			::CargoPermille <- [60,25,20,15,30];
			::CargoDecay <- [0.4,0.2,0.2,0.1,0.1];
			break;
    case(22): //SPI 1.32 - full set
			::CargoCat <- [[0,2],
				       [28],
				       [5,11,15,29],
				       [4,6,7,10,12,13,14,18,19,21,22,31],
				       [1,3,8,16,17,20,24,26,27]];
			::CargoCatList <- [CatLabels.PAXMAIL,CatLabels.G_FOOD,CatLabels.G_GOODS,
					   CatLabels.RAW_IND,CatLabels.TR_IND];
			::CargoMinPopDemand <- [0,1000,1000,1000,1000];
			::CargoPermille <- [60,25,20,15,30];
			::CargoDecay <- [0.4,0.2,0.2,0.1,0.1];
			break;    
		default:
			break;
	}

	ConfigureCategories();
}

/* Merge categories if required by settings. */
function ConfigureCategories()
{
	local merge_2_3 = GSController.GetSetting("merge_cat_2_3");
	local merge_4_5 = GSController.GetSetting("merge_cat_4_5");
	local first_idx = null;

	if (merge_2_3) {
		first_idx = 1;
		::CargoCat[first_idx].extend(::CargoCat[first_idx+1]);
		::CargoCat[first_idx].sort();
		::CargoCat.remove(first_idx+1);
		::CargoCatList.remove(first_idx);
		::CargoPermille[first_idx] += ::CargoPermille[first_idx+1];
		::CargoPermille.remove(first_idx+1);
		::CargoMinPopDemand.remove(first_idx+1);
		::CargoDecay.remove(first_idx+1);
	}
	if (merge_4_5) {
		merge_2_3 ? first_idx = 2 : first_idx = 3;
		::CargoCat[first_idx].extend(::CargoCat[first_idx+1]);
		::CargoCat[first_idx].sort();
		::CargoCat.remove(first_idx+1);
		::CargoCatList.remove(first_idx);
		::CargoCatList[first_idx] = CatLabels.G_IND;
		::CargoPermille[first_idx] += ::CargoPermille[first_idx+1];
		::CargoPermille.remove(first_idx+1);
		::CargoMinPopDemand.remove(first_idx+1);
		::CargoDecay.remove(first_idx+1);
	}
}

/* This function compares the ingame initial cargo list to the
 * industry sets and cargoscheme supported by the script. Return false
 * if they don't match.
 */
function CheckInitialCargoList() {
	local cargo_list = [];
	for(local i = 0; i < 32; ++i) {
		cargo_list.append(GSCargo.GetCargoLabel(i));
	}
	FillCargoIDList();

	// Comparing actual list to original list
	for (local i = 0; i < 32; i++) {
		if (cargo_list[i] != ::CargoIDList[i]) {
			::CargoIDList = false;
			Log.Info("Warning: game's cargo list differ from settings.", Log.LVL_INFO);
			return;
		}
	}
}

/* Initialization of cargo data. */
function InitCargoLists()
{
	DebugCargoLabels();       // Debug info: print cargo labels

	CheckInitialCargoList()   // Check if cargo list matches the settings

	DefineCargosBySettings(); // Define cargo data accordingly to industry set

	// Building a general list of all cargos, ordered by categories.
	::CargoList <- [];
	for (local i = 0; i < ::CargoCat.len(); i++) {
		for (local j = 0; j < ::CargoCat[i].len(); j++) {
			::CargoList.append(CargoCat[i][j]);
		}
	}

	// Initializing some useful and often used variables
	::CargoTypeNum <- ::CargoList.len();
	::CargoCatNum <- ::CargoCat.len();
}
