/*
 * This file is part of Renewed World Disorder, a GameScript for OpenTTD.
 * This script is more than 90% based on the Renewed City Growth script written by keoz
 * Copyright (C) 2013-2014 keoz, 2020 LaChupacabra
 *
 * It's free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the
 * Free Software Foundation, version 2 of the License.
 *
 */


require("version.nut");

class MainClass extends GSInfo
	{
	function GetAuthor()		{ return "keoz (mod by LaChupacabra)"; }
	function GetName()		{ return "Renewed World Disorder"; }
	function GetShortName() 	{ return "NRWD"; }
	function GetDescription()	{ return "Modified version of RCG script, adapted to FIRS 3 and many others sets."; }
	function GetURL()		{ return "www.tt-forum.net"; }
	function GetVersion()		{ return SELF_VERSION; }
	function GetDate()		{ return "2020-06-30"; }
	function GetAPIVersion()	{ return "1.4"; }
	function MinVersionToLoad()	{ return 3; }
	function CreateInstance()	{ return "MainClass"; }
	function GetSettings() {

		AddSetting({ name = "industry_NewGRF",
				description = "Which industry set is being used?",
				easy_value = 1,
				medium_value = 1,
				hard_value = 1,
				custom_value = 1,
				flags = CONFIG_NONE, min_value = 1, max_value = 22 });
		AddLabels("industry_NewGRF", { _1 = "Baseset: Temperate",
					_2 = "Baseset: Arctic",
					_3 = "Baseset: Tropical",
					_4 = "Baseset: Toyland",
					_5 = "OpenGFX+ / Manpower (see readme.txt)",  
					_6 = "FIRS 3.0.12: Temperate Basic",
					_7 = "FIRS 3.0.12: Arctic Basic",
					_8 = "FIRS 3.0.12: Tropic Basic",
					_9 = "FIRS 3.0.12: Steeltown",
					_10 = "FIRS 3.0.12: In a hot country",
          _11 = "FIRS 3.0.12: Extreme",   
					_12 = "FIRS 1.4.4M: Temperate basic",
					_13 = "FIRS 1.4.4M: Arctic basic",
					_14 = "FIRS 1.4.4M: Tropic Basic",
					_15 = "FIRS 1.4.4M: Heart of Darkness",
          _16 = "FIRS 1.4.4M: Firs economy",
					_17 = "ECS 1.2 (all vectors)",
					_18 = "YETI 0.1.6: tired yetis",
          _19 = "AuzInd2",
          _20 = "NAIS 1.0.6",
          _21 = "FERNZ 6057M"
					_22 = "SPI 1:32: Full set" });

		AddSetting({ name = "goal_scale_factor",
				description = "Towns demand (easy = 60, normal = 100, hard = 140)",
				easy_value = 60,
				medium_value = 100,
				hard_value = 100,
				custom_value = 100,
				flags = CONFIG_INGAME, min_value = 1, max_value = 1000, step_size = 20 });

		AddSetting({ name = "town_growth_factor",
				description = "Towns growth speed (fast = 40, normal = 80, slow = 120)",
				easy_value = 80,
				medium_value = 80,
				hard_value = 80,
				custom_value = 80,
				flags = CONFIG_INGAME, min_value = 20, max_value = 1000, step_size = 20 });

		AddSetting({ name = "merge_cat_2_3",
				description = "Merge categories 2 (Buildings) and 3 (Trade) into one (see readme.txt)",
				easy_value = 0,
				medium_value = 0,
				hard_value = 0,
				custom_value = 0,
				flags = CONFIG_BOOLEAN });

		AddSetting({ name = "merge_cat_4_5",
				description = "Merge categories 4 (Light Ind.) and 5 (Heavy Ind.) into one (see readme.txt)",
				easy_value = 0,
				medium_value = 0,
				hard_value = 0,
				custom_value = 0,
				flags = CONFIG_BOOLEAN });

		AddSetting({ name = "use_town_sign",
				description = "Show growth rate text under town names",
				easy_value = 1,
				medium_value = 1,
				hard_value = 1,
				custom_value = 1,
				flags = CONFIG_BOOLEAN });

		AddSetting({ name = "supply_impacting_part",
				description = "Expert setting: tolerance for lack of supply",
				easy_value = 80,
				medium_value = 80,
				hard_value = 80,
				custom_value = 80,
				flags = CONFIG_INGAME, min_value = 0, max_value = 100, step_size = 5 });

		AddSetting({ name = "exponentiality_factor",
				description = "Expert setting: TGR growth exponentiality factor",
				easy_value = 3,
				medium_value = 3,
				hard_value = 3,
				custom_value = 3,
				flags = CONFIG_INGAME, min_value = 1, max_value = 5 });

		AddSetting({ name = "lowest_town_growth_rate",
				description = "Expert setting: lowest TGR if requirements are not meet",
				easy_value = 880,
				medium_value = 880,
				hard_value = 880,
				custom_value = 880,
				flags = CONFIG_INGAME, min_value = 10, max_value = 880, step_size = 10 });

		AddSetting({ name = "log_level",
				description = "Debug: Log level (higher = print more)",
				easy_value = 1,
				medium_value = 1,
				hard_value = 1,
				custom_value = 1,
				flags = CONFIG_INGAME, min_value = 1, max_value = 3 });
		AddLabels("log_level", { _1 = "1: Info", _2 = "2: (unused)", _3 = "3: Debug" });
	}
}

RegisterGS(MainClass());
